abstract class MainLayout
  include Lucky::HTMLPage

  # 'needs current_user : User' makes it so that the current_user
  # is always required for pages using MainLayout
  needs current_user : User

  abstract def content
  abstract def page_title

  # MainLayout defines a default 'page_title'.
  #
  # Add a 'page_title' method to your indivual pages to customize each page's
  # title.
  #
  # Or, if you want to require every page to set a title, change the
  # 'page_title' method in this layout to:
  #
  #    abstract def page_title : String
  #
  # This will force pages to define their own 'page_title' method.
  def page_title
    "Welcome"
  end

  def render
    html_doctype

    html lang: "en" do
      mount Shared::LayoutHead, page_title: page_title

      body do
        mount Shared::FlashMessages, context.flash
        nav class: "navbar navbar-default" do
          div class: "col-xs-6" do
            div class: "pull-left" do
              # - if user_signed_in?
              # a.btn.btn-md href="/" = current_user.name
              a "Home", class: "btn btn-md", href: "/"
              a "Sitemap", class: "btn btn-md", href: "/sitemap"
              a "Register", class: "btn btn-md", href: "/users/register"
              a "Login", class: "btn btn-md", href: "/users/login"
              # - if Wikicr::ACL.permitted?(current_user, "/admin/users", Acl::Perm::Read)
              a "Users", class: "btn btn-md", href: "/admin/users"
              # - if Wikicr::ACL.permitted?(current_user, "/admin/acls", Acl::Perm::Read)
              a "ACLs", class: "btn btn-md", href: "/admin/acls"
            end
          end

          div class: "col-xs-6" do
            div class: "pull-right" do
              form flow_id: "search-page", action: "/pages/search", method: "get", role: "form" do
                div class: "input-group input-group-md" do
                  input class: "input-md form-control", name: "q", placeholder: "Search query", autocomplete: "on", list: "search-list"
                  datalist flow_id: "search-list" do
                    # - Wikicr::Page.all.each do |page|
                    #   option value=page.url = page.title
                  end
                  span class: "input-group-btn" do
                    button class: "btn.btn-md" do
                      span "Search", class: "glyphicon glyphicon-search"
                    end
                  end
                end
              end
            end
          end
        end

        nav "aria-label": "breadcrumb" do
          ol class: "breadcrumb" do
            li "History", class: "breadcrumb-item active"
            # - history.each do |page_url|
            #   li.breadcrumb-item
            #   a href=page_url
            #   - root_page = Wikicr::Page.new "/"
            #   = Wikicr::Page.one_by_url(page_url[7..-1], root_page).title
          end
        end

        render_signed_in_user
        content
      end
    end
  end

  private def render_signed_in_user
    text current_user.email
    text " - "
    link "Sign out", to: SignIns::Delete, flow_id: "sign-out-button"
  end
end
